# The Clipper C++ crystallographic library already uses the name "clipper".
# The developer is fine with the choosen name.

%define major   22
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           polyclipping
Version:        6.4.2
Release:        %mkrel 5
Summary:        Polygon clipping library
Group:          Development/C++
License:        Boost
URL:            https://sourceforge.net/projects/polyclipping
Source0:        https://downloads.sourceforge.net/%{name}/clipper_ver%{version}.zip
Patch0:         polyclipping-cmake-4.0.patch
BuildRequires:  cmake
BuildRequires:  dos2unix

%description
This library primarily performs the boolean clipping operations -
intersection, union, difference & xor - on 2D polygons. It also performs
polygon offsetting. The library handles complex (self-intersecting) polygons,
polygons with holes and polygons with overlapping co-linear edges.
Input polygons for clipping can use EvenOdd, NonZero, Positive and Negative
filling modes. The clipping code is based on the Vatti clipping algorithm,
and outperforms other clipping libraries.

%package -n     %{libname}
Summary:        %{summary}
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}


%description -n %{libname}
This library primarily performs the boolean clipping operations -
intersection, union, difference & xor - on 2D polygons. It also performs
polygon offsetting. The library handles complex (self-intersecting) polygons,
polygons with holes and polygons with overlapping co-linear edges.
Input polygons for clipping can use EvenOdd, NonZero, Positive and Negative
filling modes. The clipping code is based on the Vatti clipping algorithm,
and outperforms other clipping libraries.

%package -n     %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}


%description -n %{devname}
This package contains libraries and header files for developing applications
that use %{name}.


%prep
%setup -qc
%autopatch -p1

# Delete binaries
find . \( -name "*.exe" -o -name "*.dll" \) -delete

# Correct line ends and encodings
find . -type f -exec dos2unix -k {} \;

for filename in perl/perl_readme.txt README; do
  iconv -f iso8859-1 -t utf-8 "${filename}" > "${filename}".conv && \
    touch -r "${filename}" "${filename}".conv && \
    mv "${filename}".conv "${filename}"
done

# Enable use_lines
sed -i 's|^//#define use_lines$|#define use_lines|' cpp/clipper.hpp

%build
%global _vpath_srcdir cpp
# Use VERSION argument so that it's added to the pkgconfig file
%cmake -DVERSION=%{version}
%cmake_build


%install
%cmake_install
# from Fedora, but I can't see any need for this
# Install agg header with corrected include statement
# sed -e 's/\.\.\/clipper\.hpp/clipper.hpp/' < cpp/build/cpp_agg/agg_conv_clipper.h > %%{buildroot}%%{_includedir}/%%{name}/agg_conv_clipper.h

mv -f %{buildroot}%{_datadir}/pkgconfig/ %{buildroot}%{_libdir}/

%files -n       %{libname}
%doc License.txt README
%doc "Third Party/Haskell" "Third Party/perl" "Third Party/ruby" "Third Party/python" Documentation
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n       %{devname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc


%changelog
* Thu Jun 26 2025 daviddavid <daviddavid> 6.4.2-5.mga10
+ Revision: 2197894
- fix build with cmake 4.0
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild

* Thu Mar 17 2022 umeabot <umeabot> 6.4.2-4.mga9
+ Revision: 1797293
- Mageia 9 Mass Rebuild
+ danf <danf>
- Switch URLs from http: to https:

* Fri Feb 14 2020 umeabot <umeabot> 6.4.2-3.mga8
+ Revision: 1516122
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Sep 23 2018 umeabot <umeabot> 6.4.2-2.mga7
+ Revision: 1300341
- Mageia 7 Mass Rebuild

* Sun Mar 05 2017 akien <akien> 6.4.2-1.mga6
+ Revision: 1088760
- Version 6.4.2

* Sun Sep 11 2016 akien <akien> 6.4-1.mga6
+ Revision: 1051566
- Version 6.4

* Mon Feb 08 2016 umeabot <umeabot> 6.2.1-3.mga6
+ Revision: 950580
- Mageia 6 Mass Rebuild

* Sat Nov 08 2014 wally <wally> 6.2.1-2.mga5
+ Revision: 796058
- fix includedir in pkgconfig .pc file

* Thu Nov 06 2014 spuhler <spuhler> 6.2.1-1.mga5
+ Revision: 795980
- upgrade to ver. 6.2.1
 * libmajor changed to 19

* Wed Oct 15 2014 umeabot <umeabot> 6.1.3a-9.mga5
+ Revision: 739556
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 6.1.3a-8.mga5
+ Revision: 687717
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 wally <wally> 6.1.3a-7.mga5
+ Revision: 672602
- provide real pkg version with pkgconfig .pc file

* Sat Jun 14 2014 akien <akien> 6.1.3a-6.mga5
+ Revision: 636065
- Duplicate the %%description for %%libname, %%desc does not seem to work

* Wed Jun 11 2014 akien <akien> 6.1.3a-5.mga5
+ Revision: 635640
- Fix erroneous include dir in pkgconfig file

* Wed Jun 11 2014 akien <akien> 6.1.3a-4.mga5
+ Revision: 635573
- Add version to pkgconfig file

* Wed Jun 11 2014 akien <akien> 6.1.3a-3.mga5
+ Revision: 635550
- Put pkgconfig folder in %%_libdir (it seems not to work as expected in %%_datadir)

* Wed Jun 11 2014 akien <akien> 6.1.3a-2.mga5
+ Revision: 635546
- Rename lib and development package to comply with Mageia's library policy

* Thu Jun 05 2014 spuhler <spuhler> 6.1.3a-1.mga5
+ Revision: 633536
- first release after import from Fedora
- imported package polyclipping


* Fri Feb  7 2014 Volker Fröhlich <volker27@gmx.at> - 6.1.3a-2
- Enable use_lines

* Fri Feb  7 2014 Volker Fröhlich <volker27@gmx.at> - 6.1.3a-1
- New upstream release

* Fri Jan 03 2014 Miro Hrončok <mhroncok@redhat.com> - 5.1.6-4
- Added patch to solve rounding error (#1047914)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.1.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jun 25 2013 Miro Hrončok <mhroncok@redhat.com> - 5.1.6-2
- Added patch to solve upstream bug 47

* Wed Jun  5 2013 Tom Hughes <tom@compton.nu> - 5.1.6-1
- Update to 5.1.6 upstream release
- Install agg_conv_clipper.h

* Fri Mar  1 2013 Volker Fröhlich <volker27@gmx.at> - 5.1.2-1
- New upstream release

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Jan 14 2013 Volker Fröhlich <volker27@gmx.at> - 5.0.3-1
- New upstream release

* Mon Jan  7 2013 Volker Fröhlich <volker27@gmx.at> - 5.0.2-1
- New upstream release
- Convert README to UTF8
- Add python directory as documentation

* Wed Dec 26 2012 Volker Fröhlich <volker27@gmx.at> - 4.10.0-1
- New upstream release

* Sat Dec  1 2012 Volker Fröhlich <volker27@gmx.at> - 4.9.7-1
- New upstream release

* Thu Nov 15 2012 Volker Fröhlich <volker27@gmx.at> - 4.9.6-1
- New upstream release

* Thu Sep 20 2012 Volker Fröhlich <volker27@gmx.at> - 4.8.8-1
- New upstream release

* Sat Jul 21 2012 Volker Fröhlich <volker27@gmx.at> - 4.8.5-1
- New upstream release

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.7.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Apr 25 2012 Volker Fröhlich <volker27@gmx.at> - 4.7.6-2
- Ship latest upstream sources and adapt to changes in build system
- Own subdirectory in includedir
- Keep timestamps with dos2unix

* Thu Apr 12 2012 Volker Fröhlich <volker27@gmx.at> - 4.7.6-1
- Initial package
